.. role:: hidden
    :class: hidden-section

botorch.test_functions
========================================================
.. automodule:: botorch.test_functions


Abstract Test Function API
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.test_functions.base
    :members:

Synthetic Test Functions
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.test_functions.synthetic
    :members:

Multi-Fidelity Synthetic Test Functions
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.test_functions.multi_fidelity
    :members:

Multi-Objective Synthetic Test Functions
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.test_functions.multi_objective
    :members:
